package com.machine.coffee.Utils;

import android.content.Context;


public class CoffeeMachinePreferences {

    //Preferences name.
    private final static String PREFS_NAME = "CoffeeMachine";

    //Strings to name each data stored.
    private final static String WATER_LEVEL = "WaterLevel";
    private final static String COFFEE_LEVEL = "CoffeeLevel";
    private final static String GLASS_POSITION = "GlassPosition";
    private final static String TURN_ON_OFF = "TurnOnOff";

    /**
     * Method to save the last state of the water level on SharedPreferences.
     *
     * @param context contains the application context.
     * @param name is the username.
     */
    public static void setWaterLevel(final Context context,
                                     final String name) {
        final android.content.SharedPreferences settings = context.getSharedPreferences(
                PREFS_NAME, Context.MODE_PRIVATE);
        final android.content.SharedPreferences.Editor editor = settings.edit();

        editor.putString(WATER_LEVEL, name);
        editor.commit();
    }

    /**
     * Method to get the last state of the water level from SharedPreferences.
     *
     * @param context contains the application context.
     * @return the water level.
     */
    public static String getWaterLevel(Context context) {
        final android.content.SharedPreferences sharedPref = context.getSharedPreferences(
                PREFS_NAME, Context.MODE_PRIVATE);

        return sharedPref.getString(WATER_LEVEL, "none");
    }

    /**
     * Method to set the last state of the coffee level on SharedPreferences.
     *
     * @param context contains the application context.
     * @param name is the username.
     */
    public static void setCoffeeLevel(final Context context,
                                      final String name) {
        final android.content.SharedPreferences settings = context.getSharedPreferences(
                PREFS_NAME, Context.MODE_PRIVATE);
        final android.content.SharedPreferences.Editor editor = settings.edit();

        editor.putString(COFFEE_LEVEL, name);
        editor.commit();
    }

    /**
     * Method to get the last state of the coffee level from SharedPreferences.
     *
     * @param context contains the application context.
     * @return the coffee level.
     */
    public static String getCoffeeLevel(Context context) {
        final android.content.SharedPreferences sharedPref = context.getSharedPreferences(
                PREFS_NAME, Context.MODE_PRIVATE);

        return sharedPref.getString(COFFEE_LEVEL, "none");
    }

    /**
     * Method to set the last state of the glass position on Shared Preferences.
     *
     * @param context contains the application context.
     * @param name is the username.
     */
    public static void setGlassPosition(final Context context,
                                      final String name) {
        final android.content.SharedPreferences settings = context.getSharedPreferences(
                PREFS_NAME, Context.MODE_PRIVATE);
        final android.content.SharedPreferences.Editor editor = settings.edit();

        editor.putString(GLASS_POSITION, name);
        editor.commit();
    }

    /**
     * Method to get the last state of the glass position from Shared Preferences.
     *
     * @param context contains the application context.
     * @return the glass position.
     */
    public static String getGlassPosiion(Context context) {
        final android.content.SharedPreferences sharedPref = context.getSharedPreferences(
                PREFS_NAME, Context.MODE_PRIVATE);

        return sharedPref.getString(GLASS_POSITION, "none");
    }

    /**
     * Method to set the last state of the coffee machine (on/off) on SharedPreferences.
     *
     * @param context contains the application context.
     * @param name is the username.
     */
    public static void setTurnOnOff(final Context context,
                                        final String name) {
        final android.content.SharedPreferences settings = context.getSharedPreferences(
                PREFS_NAME, Context.MODE_PRIVATE);
        final android.content.SharedPreferences.Editor editor = settings.edit();

        editor.putString(TURN_ON_OFF, name);
        editor.commit();
    }

    /**
     * Method to get the last state of the coffee machine (on/off) from SharedPreferences.
     *
     * @param context contains the application context.
     * @return the coffee machine status.
     */
    public static String getTurnOnOff(Context context) {
        final android.content.SharedPreferences sharedPref = context.getSharedPreferences(
                PREFS_NAME, Context.MODE_PRIVATE);

        return sharedPref.getString(TURN_ON_OFF, "0");
    }
}
